==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/TRIXIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TRIXIndicatorDescription } from "./TRIXIndicatorDescription";
/**
 * @hidden
 */
var TRIXIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TRIXIndicatorDescriptionMetadata, _super);
    function TRIXIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TRIXIndicatorDescriptionMetadata.b = function (a) {
        if (TRIXIndicatorDescriptionMetadata.a == null) {
            TRIXIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TRIXIndicatorDescriptionMetadata.c(TRIXIndicatorDescriptionMetadata.a);
        }
        if (a.g(TRIXIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(TRIXIndicatorDescriptionMetadata.a);
    };
    TRIXIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    TRIXIndicatorDescriptionMetadata.d = function (a) {
        TRIXIndicatorDescriptionMetadata.b(a);
        a.u("TRIXIndicator", function () { return new TRIXIndicatorDescription(); });
        a.t("TRIXIndicator", TRIXIndicatorDescriptionMetadata.a);
    };
    TRIXIndicatorDescriptionMetadata.$t = markType(TRIXIndicatorDescriptionMetadata, 'TRIXIndicatorDescriptionMetadata');
    TRIXIndicatorDescriptionMetadata.a = null;
    return TRIXIndicatorDescriptionMetadata;
}(Base));
export { TRIXIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TRIXIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TRIXIndicatorDescription } from "./TRIXIndicatorDescription";
/**
 * @hidden
 */
var TRIXIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TRIXIndicatorDescriptionMetadata, _super);
    function TRIXIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TRIXIndicatorDescriptionMetadata.b = function (a) {
        if (TRIXIndicatorDescriptionMetadata.a == null) {
            TRIXIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TRIXIndicatorDescriptionMetadata.c(TRIXIndicatorDescriptionMetadata.a);
        }
        if (a.j(TRIXIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(TRIXIndicatorDescriptionMetadata.a);
    };
    TRIXIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    TRIXIndicatorDescriptionMetadata.d = function (a) {
        TRIXIndicatorDescriptionMetadata.b(a);
        a.aa("TRIXIndicator", function () { return new TRIXIndicatorDescription(); });
        a.z("TRIXIndicator", TRIXIndicatorDescriptionMetadata.a);
    };
    TRIXIndicatorDescriptionMetadata.$t = markType(TRIXIndicatorDescriptionMetadata, 'TRIXIndicatorDescriptionMetadata');
    TRIXIndicatorDescriptionMetadata.a = null;
    return TRIXIndicatorDescriptionMetadata;
}(Base));
export { TRIXIndicatorDescriptionMetadata };
